@@ -4,6 +4,7 @@ import time
 from time import sleep
 import requests
 import urllib3
+import urllib3
 import json
 from dsmigrator.logging import console
 
@@ -61,7 +62,11 @@ def LIDescribe(liruleid, url_link_final, tenant1key, url_link_final_2, tenant2ke
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "GET", url, headers=headers, data=payload, verify=cert
+                "GET",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             alllirule.append(describe)
@@ -84,7 +89,11 @@ def LIDescribe(liruleid, url_link_final, tenant1key, url_link_final_2, tenant2ke
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "POST", url, headers=headers, data=payload, verify=cert
+            "POST",
+            url,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         taskjson = json.loads(describe)
@@ -128,7 +137,11 @@ def LICustom(alllirule, alllicustomrule, url_link_final_2, tenant2key):
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "POST", url, headers=headers, data=payload, verify=cert
+                "POST",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             index = describe.find('"ID"')
